Nous reviendrons tout au long de ce guide sur cette notion de relation mais pour donner une image simple à appréhender, une relation n'est rien de plus qu'un lien **tissé** entre plusieurs objets en leur donnant un "sens spécifique".

Exemple: L'utilisation de la relation `intéresse` entre un utilisateur et un projet active la notification de changement, l'affichage en première page, etc...

Pour ajouter votre première relation, allez sur la page d'un projet dont vous voulez recevoir les notifications.

#. sur la page du projet, choississez l'action `modifier`
#. dans la boîte d'édition des liens, sélectionnez la relation `intéresse` puis, dans le menu déroulant ou la page de recherche, retrouvez votre identifiant de connexion
#. une nouvelle relation temporaire est affichée en grisée, il ne vous reste plus qu'à appuyer sur le bouton valider pour que l'application prenne compte de cet ajout
